@@ -23,7 +23,9 @@ define(function(require) {
 	var XAEnums = require('utils/XAEnums');
 	var localization = require('utils/XALangSupport');
 	var XAUtils = {};
-	require('bootstrap-notify');
+	var notify = require('bootstrap-notify');
+	var bootprompt = require('bootprompt');
+    var moment = require('moment');
 
 	// ///////////////////////////////////////////////////////
 	// Enum utility methods
@@ -208,20 +210,11 @@ define(function(require) {
 	 *            text - Plugin options
 	 */
 	XAUtils.notifyInfo = function(type, text, options) {
-		var html = '<div style="width: 245px;"><div style="min-height: 16px;"><div><span class="icon-exclamation-sign"></span>\
-			</div><h4 style="margin-top: -19px;margin-left: 15px;">Info</h4><div>'
-				+ text + '</div></div></div>';
-		if (_.isUndefined(options)) {
-			options = {
-				message : {
-					html : html,
-					text : text
-				},
-				type : 'info',
-				pausable: true
-			};
-		}
-		$('.top-right').notify(options).show();
+		$.notify({
+			icon: 'fa-fw fa fa-exclamation-circle',
+			title: '<strong>Info!</strong>',
+			message: _.escape(text)
+		});
 	};
 
 	/**
@@ -235,19 +228,13 @@ define(function(require) {
 	 *            text - Plugin options
 	 */
 	XAUtils.notifyError = function(type, text, options) {
-		var html = '<div style="width: 245px;"><div style="min-height: 16px;"><div><span class="icon-warning-sign"></span>\
-			</div><h4 style="margin-top: -19px;margin-left: 15px;">Error</h4><div>' + text + '</div></div></div>';
-		if (_.isUndefined(options)) {
-			options = {
-				message : {
-					html : html,
-					text : text
-				},
-				type : 'error',
-				pausable: true
-			};
-		}
-		$('.top-right').notify(options).show();
+		$.notify({
+			icon: 'fa-fw fa fa-exclamation-triangle',
+			title: '<strong>Error!</strong>',
+			message: _.escape(text)
+		},{
+			type: 'danger',
+		});
 	};
 
 	/**
@@ -261,19 +248,13 @@ define(function(require) {
 	 *            text - Plugin options
 	 */
 	XAUtils.notifySuccess = function(type, text, options) {
-		var html = '<div style="width: 245px;"><div style="min-height: 16px;"><div><span class="icon-ok-sign"></span>\
-							</div><h4 style="margin-top: -19px;margin-left: 15px;">Success</h4><div>'
-				+ text + '</div></div></div>';
-		if (_.isUndefined(options)) {
-			options = {
-				message : {
-					html : html
-				},
-				type : 'success',
-				pausable: true
-			};
-		}
-		$('.top-right').notify(options).show();
+		$.notify({
+			icon: 'fa-fw fa fa-check-circle',
+			title: '<strong>Success!</strong>',
+			message: _.escape(text)
+		},{
+			type: 'success'
+		});
 	};
 
 	/**
@@ -344,7 +325,7 @@ define(function(require) {
 	XAUtils.preventNavigation = function(msg, $form) {
 		window._preventNavigation = true;
 		window._preventNavigationMsg = msg;
-		$("body a, i[class^='icon-']").on("click.blockNavigation", function(e) {
+		$("body a, i[class^='fa-fw fa fa-']").on("click.blockNavigation", function(e) {
 			XAUtils.preventNavigationHandler.call(this, e, msg, $form);
 		});
 	};
@@ -355,7 +336,7 @@ define(function(require) {
 	XAUtils.allowNavigation = function() {
 		window._preventNavigation = false;
 		window._preventNavigationMsg = undefined;
-		$("body a, i[class^='icon-']").off('click.blockNavigation');
+		$("body a, i[class^='fa-fw fa fa-']").off('click.blockNavigation');
 	};
 
 	XAUtils.preventNavigationHandler = function(e, msg, $form) {
@@ -367,19 +348,26 @@ define(function(require) {
 
 			e.preventDefault();
 			e.stopImmediatePropagation();
-			bootbox.dialog(msg, [ {
-				"label" : localization.tt('btn.stayOnPage'),
-				"class" : "btn-success btn-small",
-				"callback" : function() {
+			bootprompt.dialog(
+			{
+				message: msg,
+				buttons: {
+				    noclose: {
+				        "label" : localization.tt('btn.stayOnPage'),
+						"className" : "btn-success btn-sm",
+						"callback" : function() {
+						}
+				    },
+				    cancel: {
+						"label" : localization.tt('btn.leavePage'),
+						"className" : "btn-danger btn-sm",
+						"callback" : function() {
+							XAUtils.allowNavigation();
+							target.click();
+						}
+					}
 				}
-			}, {
-				"label" : localization.tt('btn.leavePage'),
-				"class" : "btn-danger btn-small",
-				"callback" : function() {
-					XAUtils.allowNavigation();
-					target.click();
-				}
-			} ]);
+			});
 			return false;
 		}
 	};
@@ -399,35 +387,35 @@ define(function(require) {
 	};
 	
 	/**
-	 * Bootbox wrapper for alert
+	 * Bootprompt wrapper for alert
 	 * 
 	 * @param {Object}
 	 *            params - The params
 	 */
 	XAUtils.alertPopup = function(params) {
-		bootbox.hideAll();
+		bootprompt.hideAll();
 		if (params.callback == undefined) {
-			bootbox.alert(params.msg);
+			bootprompt.alert(params.msg);
 		} else {
-			bootbox.alert(params.msg, params.callback);
+			bootprompt.alert(params.msg, params.callback);
 		}
 	};
      
 	//Alert box with time set 
 	XAUtils.alertBoxWithTimeSet = function(msg) {
-		var alert = bootbox.alert(msg);
+		var alert = bootprompt.alert(msg);
     	return(setTimeout(function(){alert.modal('hide'); }, 4000));
 	}
 	
 	/**
-	 * Bootbox wrapper for confirm
+	 * Bootprompt wrapper for confirm
 	 * 
 	 * @param {Object}
 	 *            params - The params
 	 */
 	XAUtils.confirmPopup = function(params) {
-		bootbox.hideAll();
-		bootbox.confirm(params.msg, function(result) {
+		bootprompt.hideAll();
+		bootprompt.confirm(params.msg, function(result) {
 			if (result) {
 				params.callback();
 			}
@@ -484,15 +472,15 @@ define(function(require) {
 			}
 			var newGroupArr = _.map(groupArr, function(name, i) {
 				if (i >= 4)
-                                        return '<span class="label label-info float-left-margin-2" data-name='+type+' model-'+ type +'-id="'
+                                        return '<span class="badge badge-info float-left-margin-2" data-name='+type+' model-'+ type +'-id="'
 							+ id + '" style="display:none;">' + name
 							+ '</span>';
 				else if (i == 3 && groupArr.length > 4) {
 					showMoreLess = true;
-                                        return '<span class="label label-info float-left-margin-2" data-name='+type+' model-'+ type +'-id="'
+                                        return '<span class="badge badge-info float-left-margin-2" data-name='+type+' model-'+ type +'-id="'
 							+ id + '">' + name + '</span>';
 				} else
-                                        return '<span class="label label-info float-left-margin-2" data-name='+type+' model-'+ type +'-id="'
+                                        return '<span class="badge badge-info float-left-margin-2" data-name='+type+' model-'+ type +'-id="'
 							+ id + '">' + name + '</span>';
 			});
 			if (showMoreLess) {
@@ -509,7 +497,7 @@ define(function(require) {
 		} else
 			return '--';
 	};
-        XAUtils.showGroupsOrUsersForPolicy = function(rawValue, model, showType, rangerServiceDefModel) {
+        XAUtils.showGroupsOrUsersForPolicy = function(model, showType, rangerServiceDefModel) {
 		var showMoreLess = false, groupArr = [], items = [];
 		var itemList = ['policyItems','allowExceptions','denyPolicyItems','denyExceptions','dataMaskPolicyItems','rowFilterPolicyItems']
 		if(!_.isUndefined(rangerServiceDefModel)){
@@ -534,15 +522,15 @@ define(function(require) {
 			return '--';
 		var newGroupArr = _.map(groupArr, function(name, i) {
 			if (i >= 4) {
-				return '<span class="label label-info float-left-margin-2" policy-' + type
+				return '<span class="badge badge-info float-left-margin-2" policy-' + type
 						+ '-id="' + model.id + '" style="display:none;">'
 						+ _.escape(name) + '</span>';
 			} else if (i == 3 && groupArr.length > 4) {
 				showMoreLess = true;
-				return '<span class="label label-info float-left-margin-2" policy-' + type
+				return '<span class="badge badge-info float-left-margin-2" policy-' + type
 						+ '-id="' + model.id + '">' + _.escape(name) + '</span>';
 			} else {
-				return '<span class="label label-info float-left-margin-2" policy-' + type
+				return '<span class="badge badge-info float-left-margin-2" policy-' + type
 						+ '-id="' + model.id + '">' + _.escape(name) + '</span>';
 			}
 		});
@@ -565,13 +553,14 @@ define(function(require) {
 	};
 
 	XAUtils.showGroupsOrUsers = function(rawValue, model, userOrGroups) {
-                var showMoreLess = false, objArr, lastShowMoreCnt = 1, j = 1, listShownCnt = 5000;
+                var showMoreLess = false, objArr, lastShowMoreCnt = 1, j = 1, listShownCnt = 1000;
 		if (!_.isArray(rawValue) && rawValue.length == 0)
 			return '--';
-                objArr = (userOrGroups == 'groups') ? _.pluck(rawValue, 'groupName') : _.pluck(rawValue, 'userName');
+               // objArr = (userOrGroups == 'groups') ? _.pluck(rawValue, 'groupName') : _.pluck(rawValue, 'userName');
+               objArr = rawValue;
 		var newObjArr = _.map(objArr, function(name, i) {
 			if (i >= 4) {
-                                var eleStr = '', span = '<span class="label label-info float-left-margin-2" policy-' + userOrGroups
+                                var eleStr = '', span = '<span class="badge badge-info float-left-margin-2" policy-' + userOrGroups
                                         + '-id="' + model.id +'">'
                                         +  _.escape(name) + '</span>';
                                 if( (i + listShownCnt ) === (listShownCnt*j) + 4){
@@ -590,10 +579,10 @@ define(function(require) {
                                 return eleStr;
 			} else if (i == 3 && objArr.length > 4) {
 				showMoreLess = true;
-				return '<span class="label label-info float-left-margin-2" policy-' + userOrGroups
+				return '<span class="badge badge-info float-left-margin-2" policy-' + userOrGroups
                                                 + '-id="' + model.id + '">' +  _.escape(name) + '</span>';
 			} else {
-				return '<span class="label label-info float-left-margin-2" policy-' + userOrGroups
+				return '<span class="badge badge-info float-left-margin-2" policy-' + userOrGroups
                                                 + '-id="' + model.id + '">' +  _.escape(name) + '</span>';
 			}
 		});
@@ -639,6 +628,12 @@ define(function(require) {
 			} else {
 				window.location = 'login.jsp?sessionTimeout=true';
 			}
+		}else if(error.status == 400 && error.responseJSON && error.responseJSON.messageList && error.responseJSON.messageList[0].name) {
+			if(error.responseJSON.messageList[0].name == "DATA_NOT_FOUND" || error.responseJSON.messageList[0].name == "INVALID_INPUT_DATA"){
+				App.rContent.show(new vError({
+					status : error.status
+				}));
+			}
 		}
 	};
 	XAUtils.select2Focus = function(event) {
@@ -845,6 +840,11 @@ define(function(require) {
                     collection.state.order == 1 ? sortparams['sortType'] = "descending" : sortparams['sortType'] = "ascending";
                     urlLabelParam = _.extend(urlLabelParam, sortparams)
                 }
+                //set excludeServiceUser value to url
+                if(!_.isUndefined(collection.queryParams) && _.has(collection.queryParams, 'excludeServiceUser')) {
+                    var sortparams = _.pick(collection.queryParams, 'excludeServiceUser');
+                    urlLabelParam = _.extend(urlLabelParam, sortparams)
+                }
             }
             XAUtils.changeParamToUrlFragment(urlLabelParam, collection.modelName);
 			collection.fetch({
@@ -941,7 +941,6 @@ define(function(require) {
 		$el.parents('body').find('.datepicker').hide();
 		input.datepicker({
 			autoclose : true,
-                        dateFormat : 'yy-mm-dd',
 		}).on('changeDate', function(ev) {
 			callback(ev.date);
 			input.datepicker("hide");
@@ -1085,7 +1084,7 @@ define(function(require) {
 		}
 	};
 	XAUtils.customXEditableForPolicyCond = function(template,selectionList) {
-		// $.fn.editable.defaults.mode = 'inline';
+		// $.fn.editable.defaults.mode = 'list-inline';
 
 		var PolicyConditions = function(options) {
 			this.init('policyConditions', options, PolicyConditions.defaults);
@@ -1456,12 +1455,12 @@ define(function(require) {
         var showMoreLess = false;
         var newLabelArr = _.map(rawValue, function(name, i) {
             if (i >= 4) {
-                return '<span class="label label-info float-left-margin-2 shorten-label" title="'+ _.escape(name) +'" policy-label-id ="'+ model.id +'" style="display:none;">'+ _.escape(name) + '</span>';
+                return '<span class="badge badge-info float-left-margin-2 shorten-label" title="'+ _.escape(name) +'" policy-label-id ="'+ model.id +'" style="display:none;">'+ _.escape(name) + '</span>';
             } else if (i == 3 && rawValue.length > 4) {
                 showMoreLess = true;
-                return '<span class="label label-info float-left-margin-2 shorten-label" title="'+ _.escape(name) +'" policy-label-id ="'+ model.id +'">' + _.escape(name) + '</span>';
+                return '<span class="badge badge-info float-left-margin-2 shorten-label" title="'+ _.escape(name) +'" policy-label-id ="'+ model.id +'">' + _.escape(name) + '</span>';
             } else {
-                return '<span class="label label-info float-left-margin-2 shorten-label" title="'+ _.escape(name) +'" policy-label-id ="'+ model.id +'">' + _.escape(name) + '</span>';
+                return '<span class="badge badge-info float-left-margin-2 shorten-label" title="'+ _.escape(name) +'" policy-label-id ="'+ model.id +'">' + _.escape(name) + '</span>';
             }
         });
         if (showMoreLess) {
@@ -1513,6 +1512,7 @@ define(function(require) {
         $('.datepicker').remove();
         $('.popover').remove();
         $('.datetimepicker').remove();
+        $('body').removeClass('modal-open')
     };
     //select2 option
     XAUtils.select2OptionForUserCreateChoice = function(){
@@ -1522,7 +1522,7 @@ define(function(require) {
                 closeOnSelect : true,
                 width :'220px',
                 allowClear: true,
-                tokenSeparators: ["," , " "],
+                tokenSeparators: [" "],
                 minimumInputLength: 1,
                 initSelection : function (element, callback) {
                     var data = [];
@@ -1532,9 +1532,11 @@ define(function(require) {
                         return;
                     }
                     //this is form multi-select value
-                    $(element.val().split(",")).each(function () {
-                        data.push({id: this, text: this});
-                    });
+                    if(_.isArray(JSON.parse(element.val()))) {
+                        $(JSON.parse(element.val())).each(function () {
+                            data.push({id: this, text: this});
+                        })
+                    }
                     callback(data);
                 },
                 createSearchChoice: function(term, data) {
@@ -1546,12 +1548,18 @@ define(function(require) {
                             return null;
                         }else{
                             return {
-                                id : term,
+                                id : "<b><i class='text-muted-select2'>Create</i></b> " + term,
                                 text: term
                             };
                         }
                     }
                 },
+                formatResult : function(result){
+                    return result.id;
+                },
+                formatSelection : function(result){
+                    return result.text;
+                },
             };
 
         return opts;
@@ -1647,27 +1655,27 @@ define(function(require) {
         });
     }
 
-    XAUtils.getUsersGroupsList = function($select, domElement){
+    XAUtils.getUsersGroupsList = function($select, domElement, width, auditFilter){
         var that = domElement,
             tags = [],
             placeholder = $select === 'users' ? "Select User" : $select === 'groups' ? "Select Group" : "Select Role",
             searchUrl = $select === 'users' ? "service/xusers/lookup/users" : $select === 'groups' ? "service/xusers/lookup/groups"
                 : "service/roles/roles";
-            // if(that.model && !_.isEmpty(that.model.get('name'))){
-            //     tags.push({
-            //         'id': _.escape(that.model.get('name')),
-            //         'text': _.escape(that.model.get('name'))
-            //     });
-            //     domElement.ui['selectUsersOrGroups'].val(tags.map(function(val) {
-            //         return val.text
-            //     }));
-            // }
+            if(that.model && !_.isEmpty(that.model.get($select))){
+                _.map (that.model.get($select) , function(name){
+                    tags.push({
+	                    'id': _.escape(name),
+	                    'text': _.escape(name)
+	                });
+                })
+            }
 
         return {
             closeOnSelect : true,
             placeholder   : placeholder,
+            separator : "@-undefined-@",
             tags : true,
-            width : '300px',
+            width : width,
             initSelection: function(element, callback) {
                 callback(tags);
             },
@@ -1675,10 +1683,16 @@ define(function(require) {
                 url: searchUrl,
                 dataType: 'json',
                 data: function(term, page) {
-                    return {
-                        name: term,
-                        isVisible : XAEnums.VisibilityStatus.STATUS_VISIBLE.value,
-                    };
+                    if($select === 'roles') {
+                        return {
+                            roleNamePartial: term
+                        }
+                    } else {
+                        return {
+                            name: term,
+                            isVisible : XAEnums.VisibilityStatus.STATUS_VISIBLE.value,
+                        }
+                    }
                 },
                 results: function(data, page) {
                     var results = [],
@@ -1687,7 +1701,9 @@ define(function(require) {
                     if (data.totalCount != "0") {
                         //remove users {USER} and {OWNER}
                         if ($select == 'users' || $select == 'groups') {
-                            data.vXStrings = _.reject(data.vXStrings, function(m){return (m.value == '{USER}' || m.value == '{OWNER}')})
+                            if (_.isUndefined(auditFilter)) {
+                                data.vXStrings = _.reject(data.vXStrings, function(m){return (m.value == '{USER}' || m.value == '{OWNER}')})
+                            }
                             results = data.vXStrings.map(function(m) {
                                 return {
                                     id: _.escape(m.value),
@@ -1710,8 +1726,14 @@ define(function(require) {
                         //remove selected values
                         if(that.collection && that.collection.models){
                             _.filter(that.collection.models, function(model){
-                                if(model && !_.isUndefined(model.get('name'))){
-                                    selectedVals.push(model.get('name'));
+                                if(auditFilter !== "auditFilter"){
+                                    if(model && !_.isUndefined(model.get('name'))){
+                                        selectedVals.push(model.get('name'));
+                                    }
+                                } else {
+                                    if(model && !_.isUndefined(model.get($select))){
+                                        selectedVals = model.get($select);
+                                    }
                                 }
                             })
                         }
@@ -1803,7 +1825,7 @@ define(function(require) {
 
     //Add visual search query parameter to URL
     XAUtils.changeParamToUrlFragment = function(obj, modelName) {
-        var App = require('App');
+	var App = require('App');
         var baseUrlFregment = Backbone.history.fragment.split('?')[0],
         str = [];
         for (var p in obj) {
@@ -1819,7 +1841,7 @@ define(function(require) {
         }
         if(App.vZone && App.vZone.vZoneName && !_.isEmpty(App.vZone.vZoneName) && !obj.hasOwnProperty("securityZone") &&
             modelName && (modelName === "RangerServiceDef" || modelName === "RangerPolicy")) {
-                str.push(encodeURIComponent("securityZone")+"="+ encodeURIComponent(App.vZone.vZoneName));
+		str.push(encodeURIComponent("securityZone")+"="+ encodeURIComponent(App.vZone.vZoneName));
         }
         if( _.isEmpty(str)) {
             Backbone.history.navigate(baseUrlFregment , false);
@@ -1888,5 +1910,132 @@ define(function(require) {
         }
     }
 
+    //Separate query parameters string from URL hash
+    XAUtils.urlQueryParams = function() {
+    	var urlHash = Backbone.history.location.hash;
+    	return urlHash.indexOf("?") !== -1 ? urlHash.substring(urlHash.indexOf("?") + 1) : undefined;
+    }
+
+    XAUtils.resizeableColumn = function (self, columnName) {
+        self.rTableList.$el.find('.'+columnName).resizable({
+            maxHeight : 20,
+            stop: function (event, ui) {
+                ui.element.css('min-width', ui.size.width);
+                localStorage.setItem(columnName+'ColWidth', ui.size.width);
+            }
+        });
+        if(localStorage.getItem(columnName+'ColWidth') !== null) {
+            self.rTableList.$el.find('.'+columnName).css('min-width', +localStorage.getItem(columnName+'ColWidth'));
+        }
+    }
+
+    XAUtils.setIdleActivityTime = function() {
+        var App = require('App');
+        var INACTIVITY_TIME_OUT = 900;
+        if (App.userProfile && App.userProfile.get('configProperties') && App.userProfile.get('configProperties').inactivityTimeout) {
+            INACTIVITY_TIME_OUT = parseInt(App.userProfile.get('configProperties').inactivityTimeout);
+        }
+        INACTIVITY_TIME_OUT *= 1000;
+        localStorage.setItem('idleTimeOut', moment().add(INACTIVITY_TIME_OUT, 'milliseconds').valueOf());
+        localStorage.setItem('idleTimerLoggedOut', false);
+        XAUtils.setIdleActivityTime = function () {
+            localStorage.setItem('idleTimeOut', moment().add(INACTIVITY_TIME_OUT, 'milliseconds').valueOf());
+            var isLoggedOut = localStorage.getItem('idleTimerLoggedOut') == "true";
+            if (isLoggedOut) {
+                localStorage.setItem('idleTimerLoggedOut', false);
+            }
+            XAUtils.startIdealActivityInterval()
+        }
+        XAUtils.setIdleActivityTime();
+    };
+
+    XAUtils.startIdealActivityInterval = function () {
+        clearInterval(XAUtils.activityIntervalID)
+        XAUtils.activityIntervalID = setInterval(function() {
+            var idleTimeVal = parseInt(localStorage.getItem('idleTimeOut'));
+            if(moment().isAfter(moment(idleTimeVal))) {
+                clearInterval(XAUtils.activityIntervalID)
+                var isLoggedOut = localStorage.getItem('idleTimerLoggedOut') == "true";
+                if(isLoggedOut) {
+                    localStorage.setItem('idleTimerLoggedOut', 'false');
+                    XAUtils.idleActivityLogout();
+                } else {
+                    XAUtils.idleTimePopup();
+                }
+            }
+        }, 2000);
+    };
+
+    XAUtils.idleTimePopup = function() {
+        var timeLeft = 15;
+        var $elem = '<div id="Timer"></div>';
+
+        function countdown() {
+            var idleTimeVal = parseInt(localStorage.getItem('idleTimeOut'));
+            if (timeLeft == 0 ) {
+                clearTimeout(timerId);
+                if (!moment().isAfter(moment(idleTimeVal))) {
+                    bootprompt.hideAll()
+                } else {
+                    localStorage.setItem('idleTimerLoggedOut', 'false');
+                    XAUtils.idleActivityLogout();
+                }
+            } else {
+                var isLoggedOut = localStorage.getItem('idleTimerLoggedOut') == "true";
+                if(isLoggedOut) {
+                    clearTimeout(timerId);
+                    localStorage.setItem('idleTimerLoggedOut', 'false');
+                    XAUtils.idleActivityLogout();
+                } else if (!moment().isAfter(moment(idleTimeVal))) {
+                    bootprompt.hideAll()
+                    clearTimeout(timerId);
+                } else {
+                    $.find('#Timer')[0].innerHTML ='Time left : '+ timeLeft + ' seconds remaining';
+                    timeLeft--;
+                }
+            }
+        }
+        bootprompt.dialog({
+            title: 'Session Expiration Warning',
+            message: '<span class="inline-block">' + localization.tt('dialogMsg.idleTimeOutMsg') +'<br>'+ $elem + '</span>',
+            closeButton: false,
+            buttons: {
+                noclose: {
+                    "label" : localization.tt('btn.stayLoggdedIn'),
+                    "className" : "btn-success btn-sm stayLoggdedIn-popup",
+                    "callback" : function() {
+                        clearTimeout(timerId);
+                        XAUtils.setIdleActivityTime()
+                    }
+                },
+                cancel: {
+                    "label" : localization.tt('btn.logOutNow'),
+                    "className" : "btn-danger btn-sm",
+                    "callback" : function() {
+                        localStorage.setItem('idleTimerLoggedOut', 'false');
+                        XAUtils.idleActivityLogout();
+                    }
+                }
+            }
+        });
+
+        var timerId = setInterval(countdown, 1000);
+
+        return false;
+    };
+
+    XAUtils.idleActivityLogout = function () {
+        var App = require('App');
+        // localStorage.setItem('idleTimerLoggedOut', true);
+        if(localStorage.getItem('idleTimerLoggedOut') == "false") {
+        	localStorage.setItem('idleTimerLoggedOut', true);
+        	App.rTopProfileBar.currentView.checkKnoxSSO();
+        }
+    };
+
+    XAUtils.pluginConfigInfo = function (serviceName) {
+       return 'By default, fallback to '+ serviceName +' ACLs are enabled. If access cannot be determined by Ranger policies, authorization will fall back to '+ serviceName +' ACLs. If this behavior needs to be changed, modify '+serviceName+' plugin config - <i>'+XAEnums.PluginConfig[serviceName].configName+'</i>.'
+    };
+
 	return XAUtils;
 });
\ No newline at end of file
